#ifndef __DMENU_DIALOG_H__
#define __DMENU_DIALOG_H__

/**
 * dmenu dialog.
 *
 * @returns TRUE if script was successful.
 */
int dmenu_switcher_dialog ( void );

void print_dmenu_options ( void );
#endif
